/*
 * Copyright (c) 2005-2007 Extreme! Lab, Indiana University. All rights reserved.
 *
 * This software is open source. See the bottom of this file for the license.
 *
 * $Id: XBayaMenu.java,v 1.12 2007/02/23 01:08:08 sshirasu Exp $
 */
package edu.indiana.extreme.xbaya.gui;

import java.awt.event.ActionEvent;
import java.awt.event.KeyEvent;

import javax.swing.AbstractAction;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;

import edu.indiana.extreme.xbaya.XBayaConstants;
import edu.indiana.extreme.xbaya.XBayaEngine;
import edu.indiana.extreme.xbaya.component.gui.ComponentMenu;
import edu.indiana.extreme.xbaya.file.gui.FileMenu;
import edu.indiana.extreme.xbaya.gpel.gui.GPELMenu;
import edu.indiana.extreme.xbaya.monitor.gui.MonitorMenu;
import edu.indiana.extreme.xbaya.mylead.gui.MyLeadMenu;
import edu.indiana.extreme.xbaya.myproxy.gui.MyProxyMenu;
import edu.indiana.extreme.xbaya.wf.gui.WorkflowMenu;

/**
 * @author Satoshi Shirasuna
 */
public class XBayaMenu implements XBayaComponent {

    private XBayaEngine engine;

    private JMenuBar menuBar;

    private WorkflowMenu workflowMenu;

    private FileMenu fileMenu;

    private GPELMenu gpelMenu;

    private MyLeadMenu myLeadMenu;

    private ComponentMenu componentMenu;

    private MonitorMenu monitorMenu;

    private MyProxyMenu myProxyMenu;

    /**
     * Constructs an XwfMenu.
     * 
     * @param engine
     */
    public XBayaMenu(XBayaEngine engine) {
        this.engine = engine;

        this.workflowMenu = new WorkflowMenu(this.engine);
        this.fileMenu = new FileMenu(this.engine);
        this.gpelMenu = new GPELMenu(this.engine);
        this.myLeadMenu = new MyLeadMenu(this.engine);
        this.componentMenu = new ComponentMenu(this.engine);
        this.monitorMenu = new MonitorMenu(this.engine);
        this.myProxyMenu = new MyProxyMenu(this.engine);

        createMenuBar();
    }

    /**
     * Returns the menu bar.
     * 
     * @return The menu bar.
     */
    public JMenuBar getSwingComponent() {
        return this.menuBar;
    }

    /**
     * Creates the menu bar.
     */
    private void createMenuBar() {

        this.menuBar = new JMenuBar();

        this.menuBar.add(this.workflowMenu.getMenu());
        this.menuBar.add(this.fileMenu.getMenu());
        this.menuBar.add(this.gpelMenu.getMenu());
        this.menuBar.add(this.myLeadMenu.getMenu());
        this.menuBar.add(this.componentMenu.getMenu());
        this.menuBar.add(this.monitorMenu.getMenu());
        this.menuBar.add(this.myProxyMenu.getMenu());

        // Space before Help
        // this.menuBar.add(Box.createHorizontalGlue());

        this.menuBar.add(createHelpMenu());
    }

    private JMenu createHelpMenu() {
        // Help
        JMenu helpMenu = new JMenu("Help");
        helpMenu.setMnemonic(KeyEvent.VK_H);

        JMenuItem aboutItem = new JMenuItem("About "
                + XBayaConstants.APPLICATION_SHORT_NAME);
        aboutItem.setMnemonic(KeyEvent.VK_A);
        aboutItem.addActionListener(new AbstractAction() {
            private AboutWindow window;

            public void actionPerformed(ActionEvent event) {
                if (this.window == null) {
                    this.window = new AboutWindow(XBayaMenu.this.engine);
                }
                this.window.show();
            }
        });
        helpMenu.add(aboutItem);

        return helpMenu;
    }
}

/*
 * Indiana University Extreme! Lab Software License, Version 1.2
 * 
 * Copyright (c) 2005-2007 The Trustees of Indiana University. All rights
 * reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1) All redistributions of source code must retain the above copyright notice,
 * the list of authors in the original source code, this list of conditions and
 * the disclaimer listed in this license;
 * 
 * 2) All redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the disclaimer listed in this license in
 * the documentation and/or other materials provided with the distribution;
 * 
 * 3) Any documentation included with all redistributions must include the
 * following acknowledgement:
 * 
 * "This product includes software developed by the Indiana University Extreme!
 * Lab. For further information please visit http://www.extreme.indiana.edu/"
 * 
 * Alternatively, this acknowledgment may appear in the software itself, and
 * wherever such third-party acknowledgments normally appear.
 * 
 * 4) The name "Indiana University" or "Indiana University Extreme! Lab" shall
 * not be used to endorse or promote products derived from this software without
 * prior written permission from Indiana University. For written permission,
 * please contact http://www.extreme.indiana.edu/.
 * 
 * 5) Products derived from this software may not use "Indiana University" name
 * nor may "Indiana University" appear in their name, without prior written
 * permission of the Indiana University.
 * 
 * Indiana University provides no reassurances that the source code provided
 * does not infringe the patent or any other intellectual property rights of any
 * other entity. Indiana University disclaims any liability to any recipient for
 * claims brought by any other entity based on infringement of intellectual
 * property rights or otherwise.
 * 
 * LICENSEE UNDERSTANDS THAT SOFTWARE IS PROVIDED "AS IS" FOR WHICH NO
 * WARRANTIES AS TO CAPABILITIES OR ACCURACY ARE MADE. INDIANA UNIVERSITY GIVES
 * NO WARRANTIES AND MAKES NO REPRESENTATION THAT SOFTWARE IS FREE OF
 * INFRINGEMENT OF THIRD PARTY PATENT, COPYRIGHT, OR OTHER PROPRIETARY RIGHTS.
 * INDIANA UNIVERSITY MAKES NO WARRANTIES THAT SOFTWARE IS FREE FROM "BUGS",
 * "VIRUSES", "TROJAN HORSES", "TRAP DOORS", "WORMS", OR OTHER HARMFUL CODE.
 * LICENSEE ASSUMES THE ENTIRE RISK AS TO THE PERFORMANCE OF SOFTWARE AND/OR
 * ASSOCIATED MATERIALS, AND TO THE PERFORMANCE AND VALIDITY OF INFORMATION
 * GENERATED USING SOFTWARE.
 */
